//______________________________________________________________________________

//            Hlavikov soubor knihovny TUSB1052.DLL verze 1.02

//______________________________________________________________________________

unit TUSB1052;

interface
uses Windows, Classes, SysUtils, Wintypes;



//______________________________________________________________ NAVRATOVE KODY


//   0      V podku
//   1      Chybn komunikan rychlost
//   2      Rozdln timeouty nebo rychlosti linek
//   3      Chyba pi vysln zprvy
//   4      Timeout - nepila dn odpov
//   5      Timeout - nepila sprvn odpov
//   6      Odpov peruena
//   7      Chyba parity odpovdi
//   8      Chybn hlavika odpovdi
//   9      Chyba CRC odpovdi
//  10      Nelze vytvoit datovou strukturu knihovny
//  11      Neplatn handle zazen
//  12      Nenalezen modul USB-1052
//  13      Nen oteven dn modul USB-1052
//  14      Zazen ji inicializovno
//  15      Chyba knihovny FTD2XX
//  16      Chyba knihovny FTD2XX (FT_ListDevices)
//  17      Chyba knihovny FTD2XX (FT_Open)
//  18      Chyba knihovny FTD2XX (FT_ResetDevice)
//  19      Chyba knihovny FTD2XX (FT_Purge)
//  20      Chyba knihovny FTD2XX (FT_SetTimeouts)
//  21      Chyba knihovny FTD2XX (FT_Close)
//  22      Modul USB-1052 neodpovdl



//_______________________________________________________________ DEFINICE TYPU

type
  TBuff    = array[0..99] of DWord;  // pole DWord (100 prvku)
  PBuff    = ^TBuff;                 // ukazatel na pole DWord



//_____________________________________________________________ EXPORTOVANE FCE

// Vsechny funkce vraci 0 v pripade uspesneho provedeni. Nenulova hodnota
// signalizuje chybu, pro jeji identifikaci lze pouzit funkci TUSB1052_Error.


function TUSB1052_Version(Ver:PDWord):DWord;                                     stdcall;
// Vraci verzi knihovny DLL (nutno vydelit 100, napr. vracena hodnota 100
// znamena verzi 1.00).

function TUSB1052_Init(PHNDL:PDWord):DWord;                                      stdcall;
// Inicializuje knihovnu, vyhleda a otevre prvni modul USB-1052.
// Nastavi default komunikacni parametry (9600Bd, timeout 10ms, 2 opakovani
// pri chybe). Vraci handle otevreneho zarizeni.

function TUSB1052_SetConfig(HNDL:DWord;Baud,Timeout,Opakovani:DWord):DWord;      stdcall;
// Nastavi komunikacni rychlost, timeout a opakovani pro komunikaci
// s moduly MicroUnit. Povolene rychlosti odpovidaji modulum MicroUnit,
// tj. 600Bd, 1200Bd, 2400Bd, 4800Bd, 9600Bd, 19200Bd, 38400Bd, 57600Bd
// a 115200Bd. Timeout, tj. max. doba cekani na zahajeni odpovedi modulu,
// je nastavitelny od 1 do 65535ms. Opakovani urcuje pocet zopakovanych volani
// na modul MicroUnit v pripade chybne komunikace, tzn. napr. pro Opakovani=2
// je na modul MicroUnit volani v pripade chyby komunikace celkem 3x.
// Pokud vyhovi default hodnoty konfigurace (viz. TUSB1052_Init), neni nutno
// tuto funkci volat.

function TUSB1052_GetConfig(HNDL:DWord;Baud,Timeout,Opakovani:PDWord):DWord;     stdcall;
// Vraci nastavenou komunikacni rychlost, timeout a opakovani pro komunikaci
// s moduly MicroUnit.

function TUSB1052_Send(HNDL:DWord;TBuff,RBuff:PBuff;StatusR,StatusP:PDWord):DWord; stdcall;
// Vysle dotaz (TBuff) na modul MicroUnit, vrati odpoved modulu (RBuff),
// Status registr modulu (StatusR) a Status prijmu (StatusP).
// TBuff a RBuff jsou pole obsahujici vyslanou resp. prijatou zpravu.
// Obsah TBuff odpovida vysilane zprave protokolu AIBus-2, bez CRC. Presny
// vyznam je uveden v popisu protokolu.
//  TBuff[0] - adresa volaneho modulu MicroUnit (0-255)
//  TBuff[1] - pozadovana funkce AIBus-2 (0,1,2,3,100,101,102,103,200)
//  TBuff[2] - pozadovana periferie modulu MicroUnit (0-255)
//  TBuff[3] - primy povel (0)
//  TBuff[4] - D1 datovy byte dotazu (0-255)
//  TBuff[5] - D2 datovy byte dotazu (0-255)
//  TBuff[6] - D3 datovy byte dotazu (0-255)
//  TBuff[7] - D4 datovy byte dotazu (0-255)
// Pole RBuff obsahuje pouze prijate datove byty odpovedi.
//  RBuff[0] - D1 datovy byte odpovedi (0-255)
//  RBuff[1] - D1 datovy byte odpovedi (0-255)
//  RBuff[2] - D1 datovy byte odpovedi (0-255)
//  RBuff[3] - D1 datovy byte odpovedi (0-255)
// StatusR obsahuje prijaty Status registr modulu.
// Ve StatusP je ulozen kod uspesnosti komunikace s modulem MicroUnit.
// Slovni popis kodu lze ziskat pomoci funkce TUSB1052_Error.

function TUSB1052_Done(PHNDL:PDWord):DWord;                                      stdcall;
// Uzavre otevreny modul USB-1052 a uvolni knihovnu z pameti.

function TUSB1052_Error(ErrCode:DWord; ErrText:PBuff):DWord;                     stdcall;
// Prevede navratovy kod na text.

//________________________________________________________________ IMPLEMENTACE

implementation


//______________________________________________________________________________

function TUSB1052_Version;                             external 'TUSB1052.DLL';
function TUSB1052_Init;                                external 'TUSB1052.DLL';
function TUSB1052_SetConfig;                           external 'TUSB1052.DLL';
function TUSB1052_GetConfig;                           external 'TUSB1052.DLL';
function TUSB1052_Send;                                external 'TUSB1052.DLL';
function TUSB1052_Done;                                external 'TUSB1052.DLL';
function TUSB1052_Error;                               external 'TUSB1052.DLL';

//______________________________________________________________________________

begin
end.


